﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;


public class Pool : MonoBehaviour 
{

	// lazy fake singleton
	public static Pool Instance;

	// gameobject to fill the pool with
	public GameObject pooledPrefab;

	// amount of instances in the pool
	public int poolSize = 10;


	// the list of all pooled objects
	Stack<GameObject> stack;

	

	void Start () 
	{
		Instance = this;
		InitPool();
	}

	
	/**
	 * Create stack and add instances of the given prefab to it.
	 */
	void InitPool()
	{
		stack = new Stack<GameObject>();
		
		for(int i = 0; i < poolSize; i++)
		{
			var obj = GameObject.Instantiate(pooledPrefab);
			obj.transform.parent = transform;
			obj.name += "_" + i.ToString();
			Push(obj);
		}
	}


	/**
	 * Pop an object from the stack to use it in the current scene.
	 */
	public GameObject Pop()
	{
		if (stack.Count > 0)
		{
			var obj = stack.Pop();
			obj.SetActive(true);
			return obj;
		}
		else
		{
			Debug.Log("Pool is empty!");
		}

		return null;
	}
	

	/**
	 * Return an object to the pool.
	 */
	public void Push(GameObject obj)
	{
		obj.transform.localPosition = Vector3.zero;
		obj.SetActive(false);
		stack.Push(obj);
	}
}
