﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using UnityEngine.UI;


public class Spawner : MonoBehaviour 
{
	List<GameObject> allObjects;

	

	void Start () 
	{
		// cache all created cubes for transform manipulations
		allObjects = new List<GameObject>();

		// Periodically spawn a new object
		InvokeRepeating("Spawn", 1, 0.6f);
		InvokeRepeating("UpdateUI", 0.1f, 0.2f);
	}



	/**
	 * Spawn a new cube at the spawner position adding some randomness to it.
	 */
	void Spawn()
	{
		var obj = Pool.Instance.Pop();
		if (obj != null)
		{
			var randomPosition = new Vector3(0, Random.Range(-5, 5), Random.Range(-2, 5));
			obj.transform.position = transform.position + randomPosition;
			obj.transform.Rotate(Random.Range(0, 360), Random.Range(0, 360), Random.Range(0, 360));

			// Store object in a list for movement stuff (see Update());
			allObjects.Add(obj);
		}
	}



	void Update()
	{

		// Move all objects. If an object x-position has reached -20 it is pushed back into the pool.
		for(int i = allObjects.Count-1; i >= 0; i--)
		{
			allObjects[i].transform.Translate(-0.1f, 0, 0, Space.World);
			allObjects[i].transform.Rotate(-1, 0, 0);

			if (allObjects[i].transform.position.x < -20)
			{
				Pool.Instance.Push(allObjects[i]);
				allObjects.RemoveAt(i);
			}
		}
	}


	// Update textfields in the UI
	void UpdateUI()
	{
		GameObject.Find("UsedLabel").GetComponent<Text>().text = string.Format("Objects in use: {0}/{1}", allObjects.Count, Pool.Instance.poolSize);
	}
	
}
